==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfListField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListField(PdfAppearanceField):
    """
    Represents base class form's list fields.
    """

    @property
    def Items(self) -> 'PdfListFieldItemCollection':
        """
        Gets the items.
        """
        GetDllLibPdf().PdfListField_get_Items.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_Items.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListField_get_Items(self.Ptr)
        ret = None if intPtr == None else PdfListFieldItemCollection(intPtr)
        return ret

    @property
    def SelectedIndex(self) -> int:
        """
        Gets or sets the first selected item in the list.
        """
        GetDllLibPdf().PdfListField_get_SelectedIndex.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_SelectedIndex.restype = c_int
        ret = GetDllLibPdf().PdfListField_get_SelectedIndex(self.Ptr)
        return ret

    @SelectedIndex.setter
    def SelectedIndex(self, value: int):
        GetDllLibPdf().PdfListField_set_SelectedIndex.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfListField_set_SelectedIndex(self.Ptr, value)

    @property
    def SelectedValue(self) -> str:
        """
        Gets or sets the value of the first selected item in the list.
        """
        GetDllLibPdf().PdfListField_get_SelectedValue.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_SelectedValue.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfListField_get_SelectedValue(self.Ptr))
        return ret

    @SelectedValue.setter
    def SelectedValue(self, value: str):
        GetDllLibPdf().PdfListField_set_SelectedValue.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfListField_set_SelectedValue(self.Ptr, value)

    @property
    def SelectedItem(self) -> 'PdfListFieldItem':
        """
        Gets the first selected item in the list.
        """
        GetDllLibPdf().PdfListField_get_SelectedItem.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_SelectedItem.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListField_get_SelectedItem(self.Ptr)
        ret = None if intPtr == None else PdfListFieldItem(intPtr)
        return ret

    @property
    def CommitOnSelChange(self) -> bool:
        """
        Gets or sets the flag indicating if a new value selected is committed immediately without waiting to leave the field.
        """
        GetDllLibPdf().PdfListField_get_CommitOnSelChange.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_CommitOnSelChange.restype = c_bool
        ret = GetDllLibPdf().PdfListField_get_CommitOnSelChange(self.Ptr)
        return ret

    @CommitOnSelChange.setter
    def CommitOnSelChange(self, value: bool):
        GetDllLibPdf().PdfListField_set_CommitOnSelChange.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfListField_set_CommitOnSelChange(self.Ptr, value)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfListField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListField(PdfAppearanceField):
    """
    Represents base class form's list fields.
    """

    @property
    def Items(self) -> 'PdfListFieldItemCollection':
        """
        Gets the items.
        """
        GetDllLibPdf().PdfListField_get_Items.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_Items.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListField_get_Items,self.Ptr)
        ret = None if intPtr == None else PdfListFieldItemCollection(intPtr)
        return ret

    @property
    def SelectedIndex(self) -> int:
        """
        Gets or sets the first selected item in the list.
        """
        GetDllLibPdf().PdfListField_get_SelectedIndex.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_SelectedIndex.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfListField_get_SelectedIndex,self.Ptr)
        return ret

    @SelectedIndex.setter
    def SelectedIndex(self, value: int):
        GetDllLibPdf().PdfListField_set_SelectedIndex.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfListField_set_SelectedIndex,self.Ptr, value)

    @property
    def SelectedValue(self) -> str:
        """
        Gets or sets the value of the first selected item in the list.
        """
        GetDllLibPdf().PdfListField_get_SelectedValue.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_SelectedValue.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfListField_get_SelectedValue,self.Ptr))
        return ret

    @SelectedValue.setter
    def SelectedValue(self, value: str):
        GetDllLibPdf().PdfListField_set_SelectedValue.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfListField_set_SelectedValue,self.Ptr, value)

    @property
    def SelectedItem(self) -> 'PdfListFieldItem':
        """
        Gets the first selected item in the list.
        """
        GetDllLibPdf().PdfListField_get_SelectedItem.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_SelectedItem.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfListField_get_SelectedItem,self.Ptr)
        ret = None if intPtr == None else PdfListFieldItem(intPtr)
        return ret

    @property
    def CommitOnSelChange(self) -> bool:
        """
        Gets or sets the flag indicating if a new value selected is committed immediately without waiting to leave the field.
        """
        GetDllLibPdf().PdfListField_get_CommitOnSelChange.argtypes = [c_void_p]
        GetDllLibPdf().PdfListField_get_CommitOnSelChange.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfListField_get_CommitOnSelChange,self.Ptr)
        return ret

    @CommitOnSelChange.setter
    def CommitOnSelChange(self, value: bool):
        GetDllLibPdf().PdfListField_set_CommitOnSelChange.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfListField_set_CommitOnSelChange,self.Ptr, value)
